# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
#
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.service_client import ServiceClient
from msrest import Serializer, Deserializer
from msrestazure import AzureConfiguration
from .version import VERSION
from .operations.lr_os_operations import LROsOperations
from .operations.lro_retrys_operations import LRORetrysOperations
from .operations.lrosa_ds_operations import LROSADsOperations
from .operations.lr_os_custom_header_operations import LROsCustomHeaderOperations
from . import models


class AutoRestLongRunningOperationTestServiceConfiguration(AzureConfiguration):
    """Configuration for AutoRestLongRunningOperationTestService
    Note that all parameters used to create this instance are saved as instance
    attributes.

    :param credentials: Credentials needed for the client to connect to Azure.
    :type credentials: :mod:`A msrestazure Credentials
     object<msrestazure.azure_active_directory>`
    :param accept_language: Gets or sets the preferred language for the
     response.
    :type accept_language: str
    :param long_running_operation_retry_timeout: Gets or sets the retry
     timeout in seconds for Long Running Operations. Default value is 30.
    :type long_running_operation_retry_timeout: int
    :param generate_client_request_id: When set to true a unique
     x-ms-client-request-id value is generated and included in each request.
     Default is true.
    :type generate_client_request_id: bool
    :param str base_url: Service URL
    :param str filepath: Existing config
    """

    def __init__(
            self, credentials, accept_language='en-US', long_running_operation_retry_timeout=30, generate_client_request_id=True, base_url=None, filepath=None):

        if credentials is None:
            raise ValueError("Parameter 'credentials' must not be None.")
        if accept_language is not None and not isinstance(accept_language, str):
            raise TypeError("Optional parameter 'accept_language' must be str.")
        if not base_url:
            base_url = 'http://localhost'

        super(AutoRestLongRunningOperationTestServiceConfiguration, self).__init__(base_url, filepath)

        self.add_user_agent('autorestlongrunningoperationtestservice/{}'.format(VERSION))
        self.add_user_agent('Azure-SDK-For-Python')

        self.credentials = credentials
        self.accept_language = accept_language
        self.long_running_operation_retry_timeout = long_running_operation_retry_timeout
        self.generate_client_request_id = generate_client_request_id


class AutoRestLongRunningOperationTestService(object):
    """Long-running Operation for AutoRest

    :ivar config: Configuration for client.
    :vartype config: AutoRestLongRunningOperationTestServiceConfiguration

    :ivar lr_os: LROs operations
    :vartype lr_os: .operations.LROsOperations
    :ivar lro_retrys: LRORetrys operations
    :vartype lro_retrys: .operations.LRORetrysOperations
    :ivar lrosa_ds: LROSADs operations
    :vartype lrosa_ds: .operations.LROSADsOperations
    :ivar lr_os_custom_header: LROsCustomHeader operations
    :vartype lr_os_custom_header: .operations.LROsCustomHeaderOperations

    :param credentials: Credentials needed for the client to connect to Azure.
    :type credentials: :mod:`A msrestazure Credentials
     object<msrestazure.azure_active_directory>`
    :param accept_language: Gets or sets the preferred language for the
     response.
    :type accept_language: str
    :param long_running_operation_retry_timeout: Gets or sets the retry
     timeout in seconds for Long Running Operations. Default value is 30.
    :type long_running_operation_retry_timeout: int
    :param generate_client_request_id: When set to true a unique
     x-ms-client-request-id value is generated and included in each request.
     Default is true.
    :type generate_client_request_id: bool
    :param str base_url: Service URL
    :param str filepath: Existing config
    """

    def __init__(
            self, credentials, accept_language='en-US', long_running_operation_retry_timeout=30, generate_client_request_id=True, base_url=None, filepath=None):

        self.config = AutoRestLongRunningOperationTestServiceConfiguration(credentials, accept_language, long_running_operation_retry_timeout, generate_client_request_id, base_url, filepath)
        self._client = ServiceClient(self.config.credentials, self.config)

        client_models = {k: v for k, v in models.__dict__.items() if isinstance(v, type)}
        self._serialize = Serializer(client_models)
        self._deserialize = Deserializer(client_models)

        self.lr_os = LROsOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.lro_retrys = LRORetrysOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.lrosa_ds = LROSADsOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.lr_os_custom_header = LROsCustomHeaderOperations(
            self._client, self.config, self._serialize, self._deserialize)
